==> zio-aws-sagemaker_2.12-5.17.130.1-sources.jar: zio/aws/sagemaker/model/CreateActionResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.ActionArn
import scala.jdk.CollectionConverters._
final case class CreateActionResponse(actionArn: Option[ActionArn] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateActionResponse = {
    import CreateActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
      .builder()
      .optionallyWith(
        actionArn.map(value => ActionArn.unwrap(value): java.lang.String)
      )(_.actionArn)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateActionResponse.ReadOnly =
    zio.aws.sagemaker.model.CreateActionResponse.wrap(buildAwsValue())
}
object CreateActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateActionResponse =
      zio.aws.sagemaker.model
        .CreateActionResponse(actionArn.map(value => value))
    def actionArn: Option[ActionArn]
    def getActionArn: ZIO[Any, AwsError, ActionArn] =
      AwsError.unwrapOptionField("actionArn", actionArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ) extends zio.aws.sagemaker.model.CreateActionResponse.ReadOnly {
    override val actionArn: Option[ActionArn] = scala
      .Option(impl.actionArn())
      .map(value => zio.aws.sagemaker.model.primitives.ActionArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ): zio.aws.sagemaker.model.CreateActionResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_2.12-5.17.295.11-sources.jar: zio/aws/sagemaker/model/CreateActionResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.ActionArn
import scala.jdk.CollectionConverters._
final case class CreateActionResponse(
    actionArn: Optional[ActionArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CreateActionResponse = {
    import CreateActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
      .builder()
      .optionallyWith(
        actionArn.map(value => ActionArn.unwrap(value): java.lang.String)
      )(_.actionArn)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CreateActionResponse.ReadOnly =
    zio.aws.sagemaker.model.CreateActionResponse.wrap(buildAwsValue())
}
object CreateActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CreateActionResponse =
      zio.aws.sagemaker.model
        .CreateActionResponse(actionArn.map(value => value))
    def actionArn: Optional[ActionArn]
    def getActionArn: ZIO[Any, AwsError, ActionArn] =
      AwsError.unwrapOptionField("actionArn", actionArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ) extends zio.aws.sagemaker.model.CreateActionResponse.ReadOnly {
    override val actionArn: Optional[ActionArn] = zio.aws.core.internal
      .optionalFromNullable(impl.actionArn())
      .map(value => zio.aws.sagemaker.model.primitives.ActionArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CreateActionResponse
  ): zio.aws.sagemaker.model.CreateActionResponse.ReadOnly = new Wrapper(impl)
}
